@@ -1,4 +1,4 @@
-# Copyright (c) 2003-2006 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2013 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -13,17 +13,55 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-"""check for signs of poor design
+"""check for signs of poor design"""
 
+from astroid import Function, If, InferenceError
 
- see http://intranet.logilab.fr/jpl/view?rql=Any%20X%20where%20X%20eid%201243
- FIXME: missing 13, 15, 16
-"""
-
-from logilab.astng import Function, If, InferenceError
-
-from pylint.interfaces import IASTNGChecker
+from pylint.interfaces import IAstroidChecker
 from pylint.checkers import BaseChecker
+from pylint.checkers.utils import check_messages
+
+import re
+
+# regexp for ignored argument name
+IGNORED_ARGUMENT_NAMES = re.compile('_.*')
+
+SPECIAL_METHODS = [('Context manager', set(('__enter__',
+                                            '__exit__',))),
+                   ('Container', set(('__len__',
+                                      '__getitem__',))),
+                   ('Mutable container', set(('__setitem__',
+                                              '__delitem__',))),
+                   ]
+
+class SpecialMethodChecker(object):
+    """A functor that checks for consistency of a set of special methods"""
+    def __init__(self, methods_found, on_error):
+        """Stores the set of __x__ method names that were found in the
+        class and a callable that will be called with args to R0024 if
+        the check fails
+        """
+        self.methods_found = methods_found
+        self.on_error = on_error
+
+    def __call__(self, methods_required, protocol):
+        """Checks the set of method names given to __init__ against the set
+        required.
+
+        If they are all present, returns true.
+        If they are all absent, returns false.
+        If some are present, reports the error and returns false.
+        """
+        required_methods_found = methods_required & self.methods_found
+        if required_methods_found == methods_required:
+            return True
+        if required_methods_found:
+            required_methods_missing = methods_required - self.methods_found
+            self.on_error((protocol,
+                           ', '.join(sorted(required_methods_found)),
+                           ', '.join(sorted(required_methods_missing))))
+        return False
+
 
 def class_is_abstract(klass):
     """return true if the given class node should be considered as an abstract
@@ -38,49 +76,65 @@ def class_is_abstract(klass):
 
 MSGS = {
     'R0901': ('Too many ancestors (%s/%s)',
+              'too-many-ancestors',
               'Used when class has too many parent classes, try to reduce \
-              this to get a more simple (and so easier to use) class.'),
+              this to get a simpler (and so easier to use) class.'),
     'R0902': ('Too many instance attributes (%s/%s)',
+              'too-many-instance-attributes',
               'Used when class has too many instance attributes, try to reduce \
-              this to get a more simple (and so easier to use) class.'),
+              this to get a simpler (and so easier to use) class.'),
     'R0903': ('Too few public methods (%s/%s)',
+              'too-few-public-methods',
               'Used when class has too few public methods, so be sure it\'s \
               really worth it.'),
     'R0904': ('Too many public methods (%s/%s)',
+              'too-many-public-methods',
               'Used when class has too many public methods, try to reduce \
-              this to get a more simple (and so easier to use) class.'),
-    
+              this to get a simpler (and so easier to use) class.'),
+
     'R0911': ('Too many return statements (%s/%s)',
+              'too-many-return-statements',
               'Used when a function or method has too many return statement, \
               making it hard to follow.'),
     'R0912': ('Too many branches (%s/%s)',
+              'too-many-branches',
               'Used when a function or method has too many branches, \
               making it hard to follow.'),
     'R0913': ('Too many arguments (%s/%s)',
+              'too-many-arguments',
               'Used when a function or method takes too many arguments.'),
     'R0914': ('Too many local variables (%s/%s)',
+              'too-many-locals',
               'Used when a function or method has too many local variables.'),
     'R0915': ('Too many statements (%s/%s)',
+              'too-many-statements',
               'Used when a function or method has too many statements. You \
               should then split it in smaller functions / methods.'),
-    
+
     'R0921': ('Abstract class not referenced',
+              'abstract-class-not-used',
               'Used when an abstract class is not used as ancestor anywhere.'),
     'R0922': ('Abstract class is only referenced %s times',
+              'abstract-class-little-used',
               'Used when an abstract class is used less than X times as \
               ancestor.'),
     'R0923': ('Interface not implemented',
+              'interface-not-implemented',
               'Used when an interface class is not implemented anywhere.'),
+    'R0924': ('Badly implemented %s, implements %s but not %s',
+              'incomplete-protocol',
+              'A class implements some of the special methods for a particular \
+               protocol, but not all of them')
     }
 
 
 class MisdesignChecker(BaseChecker):
-    """checks for sign of poor/misdesign:                                      
-    * number of methods, attributes, local variables...                        
-    * size, complexity of functions, methods                                   
+    """checks for sign of poor/misdesign:
+    * number of methods, attributes, local variables...
+    * size, complexity of functions, methods
     """
-    
-    __implements__ = (IASTNGChecker,)
+
+    __implements__ = (IAstroidChecker,)
 
     # configuration section name
     name = 'design'
@@ -92,6 +146,12 @@ class MisdesignChecker(BaseChecker):
                 {'default' : 5, 'type' : 'int', 'metavar' : '<int>',
                  'help': 'Maximum number of arguments for function / method'}
                 ),
+               ('ignored-argument-names',
+                {'default' : IGNORED_ARGUMENT_NAMES,
+                 'type' :'regexp', 'metavar' : '<regexp>',
+                 'help' : 'Argument names that match this expression will be '
+                          'ignored. Default to name with leading underscore'}
+                ),
                ('max-locals',
                 {'default' : 15, 'type' : 'int', 'metavar' : '<int>',
                  'help': 'Maximum number of locals for function / method body'}
@@ -101,7 +161,7 @@ class MisdesignChecker(BaseChecker):
                  'help': 'Maximum number of return / yield for function / '
                          'method body'}
                 ),
-               ('max-branchs',
+               ('max-branches',
                 {'default' : 12, 'type' : 'int', 'metavar' : '<int>',
                  'help': 'Maximum number of branch for function / method body'}
                 ),
@@ -143,23 +203,24 @@ class MisdesignChecker(BaseChecker):
         BaseChecker.__init__(self, linter)
         self.stats = None
         self._returns = None
-        self._branchs = None
+        self._branches = None
         self._used_abstracts = None
         self._used_ifaces = None
         self._abstracts = None
         self._ifaces = None
         self._stmts = 0
-        
+
     def open(self):
         """initialize visit variables"""
         self.stats = self.linter.add_stats()
         self._returns = []
-        self._branchs = []
+        self._branches = []
         self._used_abstracts = {}
         self._used_ifaces = {}
         self._abstracts = []
         self._ifaces = []
 
+    # Check 'R0921', 'R0922', 'R0923'
     def close(self):
         """check that abstract/interface classes are used"""
         for abstract in self._abstracts:
@@ -171,7 +232,8 @@ class MisdesignChecker(BaseChecker):
         for iface in self._ifaces:
             if not iface in self._used_ifaces:
                 self.add_message('R0923', node=iface)
-                
+
+    @check_messages('R0901', 'R0902', 'R0903', 'R0904', 'R0921', 'R0922', 'R0923')
     def visit_class(self, node):
         """check size of inheritance hierarchy and number of instance attributes
         """
@@ -201,20 +263,24 @@ class MisdesignChecker(BaseChecker):
             for iface in node.interfaces():
                 self._used_ifaces[iface] = 1
         except InferenceError:
-            # XXX log ? 
+            # XXX log ?
             pass
         for parent in node.ancestors():
             try:
                 self._used_abstracts[parent] += 1
             except KeyError:
                 self._used_abstracts[parent] = 1
-            
+
+    @check_messages('R0901', 'R0902', 'R0903', 'R0904', 'R0921', 'R0922', 'R0923')
     def leave_class(self, node):
         """check number of public methods"""
         nb_public_methods = 0
+        special_methods = set()
         for method in node.methods():
             if not method.name.startswith('_'):
                 nb_public_methods += 1
+            if method.name.startswith("__"):
+                special_methods.add(method.name)
         # Does the class contain less than 20 public methods ?
         if nb_public_methods > self.config.max_public_methods:
             self.add_message('R0904', node=node,
@@ -223,13 +289,20 @@ class MisdesignChecker(BaseChecker):
         # stop here for exception, metaclass and interface classes
         if node.type != 'class':
             return
+        # Does the class implement special methods consitently?
+        # If so, don't enforce minimum public methods.
+        check_special = SpecialMethodChecker(
+            special_methods, lambda args: self.add_message('R0924', node=node, args=args))
+        protocols = [check_special(pmethods, pname) for pname, pmethods in SPECIAL_METHODS]
+        if True in protocols:
+            return
         # Does the class contain more than 5 public methods ?
         if nb_public_methods < self.config.min_public_methods:
             self.add_message('R0903', node=node,
                              args=(nb_public_methods,
                                    self.config.min_public_methods))
 
-        
+    @check_messages('R0911', 'R0912', 'R0913', 'R0914', 'R0915')
     def visit_function(self, node):
         """check function name, docstring, arguments, redefinition,
         variable names, max locals
@@ -237,20 +310,28 @@ class MisdesignChecker(BaseChecker):
         self._inc_branch()
         # init branch and returns counters
         self._returns.append(0)
-        self._branchs.append(0)
+        self._branches.append(0)
         # check number of arguments
         args = node.args.args
-        if args is not None and len(args) > self.config.max_args:
-            self.add_message('R0913', node=node,
-                             args=(len(args), self.config.max_args))
+        if args is not None:
+            ignored_args_num = len(
+                [arg for arg in args
+                 if self.config.ignored_argument_names.match(arg.name)])
+            argnum = len(args) - ignored_args_num
+            if  argnum > self.config.max_args:
+                self.add_message('R0913', node=node,
+                                 args=(len(args), self.config.max_args))
+        else:
+            ignored_args_num = 0
         # check number of local variables
-        locnum = len(node.locals)
+        locnum = len(node.locals) - ignored_args_num
         if locnum > self.config.max_locals:
             self.add_message('R0914', node=node,
                              args=(locnum, self.config.max_locals))
         # init statements counter
         self._stmts = 1
 
+    @check_messages('R0911', 'R0912', 'R0913', 'R0914', 'R0915')
     def leave_function(self, node):
         """most of the work is done here on close:
         checks for max returns, branch, return in __init__
@@ -259,27 +340,21 @@ class MisdesignChecker(BaseChecker):
         if returns > self.config.max_returns:
             self.add_message('R0911', node=node,
                              args=(returns, self.config.max_returns))
-        branchs = self._branchs.pop()
-        if branchs > self.config.max_branchs:
+        branches = self._branches.pop()
+        if branches > self.config.max_branches:
             self.add_message('R0912', node=node,
-                             args=(branchs, self.config.max_branchs))
+                             args=(branches, self.config.max_branches))
         # check number of statements
         if self._stmts > self.config.max_statements:
             self.add_message('R0915', node=node,
                              args=(self._stmts, self.config.max_statements))
 
     def visit_return(self, _):
-        """count number of returns/yields"""
+        """count number of returns"""
         if not self._returns:
             return # return outside function, reported by the base checker
         self._returns[-1] += 1
-        
-    def visit_yield(self, _):
-        """count number of returns/yields"""
-        if not self._returns:
-            return # yield outside function, reported by the base checker
-        self._returns[-1] += 1
-        
+
     def visit_default(self, node):
         """default visit method -> increments the statements counter if
         necessary
@@ -288,42 +363,42 @@ class MisdesignChecker(BaseChecker):
             self._stmts += 1
 
     def visit_tryexcept(self, node):
-        """increments the branchs counter"""
-        branchs = len(node.handlers)
+        """increments the branches counter"""
+        branches = len(node.handlers)
         if node.orelse:
-            branchs += 1
-        self._inc_branch(branchs)
-        self._stmts += branchs
-        
+            branches += 1
+        self._inc_branch(branches)
+        self._stmts += branches
+
     def visit_tryfinally(self, _):
-        """increments the branchs counter"""
+        """increments the branches counter"""
         self._inc_branch(2)
         self._stmts += 2
-        
+
     def visit_if(self, node):
-        """increments the branchs counter"""
-        branchs = 1
+        """increments the branches counter"""
+        branches = 1
         # don't double count If nodes coming from some 'elif'
         if node.orelse and (len(node.orelse)>1 or
                             not isinstance(node.orelse[0], If)):
-            branchs += 1
-        self._inc_branch(branchs)
-        self._stmts += branchs
-        
+            branches += 1
+        self._inc_branch(branches)
+        self._stmts += branches
+
     def visit_while(self, node):
-        """increments the branchs counter"""
-        branchs = 1
+        """increments the branches counter"""
+        branches = 1
         if node.orelse:
-            branchs += 1
-        self._inc_branch(branchs)
-        
+            branches += 1
+        self._inc_branch(branches)
+
     visit_for = visit_while
 
-    def _inc_branch(self, branchsnum=1):
-        """increments the branchs counter"""
-        branchs = self._branchs
-        for i in xrange(len(branchs)):
-            branchs[i] += branchsnum
+    def _inc_branch(self, branchesnum=1):
+        """increments the branches counter"""
+        branches = self._branches
+        for i in xrange(len(branches)):
+            branches[i] += branchesnum
 
     # FIXME: make a nice report...
 
