@@ -21,13 +21,9 @@ class GUIReporter(BaseReporter):
 
     def add_message(self, msg_id, location, msg):
         """manage message of different type and in the context of path"""
-        module, obj, line = location[1:]
-        if self.include_ids:
-            sigle = msg_id
-        else:
-            sigle = msg_id[0]
-
-        full_msg = [sigle, module, obj, str(line), msg]
+        filename, module, obj, line, col_offset = location
+        msg = Message(self, msg_id, location, msg)
+        full_msg = [msg.C, msg_id, filename, module, obj, str(line), msg]
         self.msgs += [[sigle, module, obj, str(line)]]
         self.gui.msg_queue.put(full_msg)
 
