@@ -20,44 +20,30 @@ unittest for the extensions.diadefslib modules
 import unittest
 import sys
 
-from logilab import astng
-from logilab.astng import MANAGER
-from logilab.astng.inspector import Linker
+import astroid
+from astroid import MANAGER
+from astroid.inspector import Linker
 
 from pylint.pyreverse.diadefslib import *
 
 from utils import Config
 
-def astng_wrapper(func, modname):
+def astroid_wrapper(func, modname):
     return func(modname)
 
-PROJECT = MANAGER.project_from_files(['data'], astng_wrapper)
+PROJECT = MANAGER.project_from_files(['data'], astroid_wrapper)
 
 CONFIG = Config()
 HANDLER = DiadefsHandler(CONFIG)
 
 def _process_classes(classes):
     """extract class names of a list"""
-    result = []
-    for classe in classes:
-        result.append({'node' : isinstance(classe.node, astng.Class),
-                       'name' : classe.title})
-    result.sort()
-    return result
-
-def _process_modules(modules):
-    """extract module names from a list"""
-    result = []
-    for module in modules:
-        result.append({'node' : isinstance(module.node, astng.Module),
-                       'name': module.title})
-    result.sort()
-    return result
+    return sorted([(isinstance(c.node, astroid.Class), c.title) for c in classes])
 
 def _process_relations(relations):
     """extract relation indices from a relation list"""
     result = []
-    for rel_type, rels  in relations.items():
+    for rel_type, rels  in relations.iteritems():
         for rel in rels:
             result.append( (rel_type, rel.from_object.title,
                             rel.to_object.title) )
@@ -109,17 +95,18 @@ class DefaultDiadefGeneratorTC(unittest.TestCase):
         self.assertEqual(keys, ['package', 'class'])
         pd = dd[0]
         self.assertEqual(pd.title, 'packages No Name')
-        modules = _process_modules(pd.objects)
-        self.assertEqual(modules, [{'node': True, 'name': 'data'},
-                                    {'node': True, 'name': 'data.clientmodule_test'},
-                                    {'node': True, 'name': 'data.suppliermodule_test'}])
+        modules = sorted([(isinstance(m.node, astroid.Module), m.title)
+                         for m in pd.objects])
+        self.assertEqual(modules, [(True, 'data'),
+                                   (True, 'data.clientmodule_test'),
+                                   (True, 'data.suppliermodule_test')])
         cd = dd[1]
         self.assertEqual(cd.title, 'classes No Name')
         classes = _process_classes(cd.objects)
-        self.assertEqual(classes, [{'node': True, 'name': 'Ancestor'},
-                                    {'node': True, 'name': 'DoNothing'},
-                                    {'node': True, 'name': 'Interface'},
-                                    {'node': True, 'name': 'Specialization'}]
+        self.assertEqual(classes, [(True, 'Ancestor'),
+                                   (True, 'DoNothing'),
+                                   (True, 'Interface'),
+                                   (True, 'Specialization')]
                           )
 
     _should_rels = [('association', 'DoNothing', 'Ancestor'),
@@ -138,7 +125,7 @@ class DefaultDiadefGeneratorTC(unittest.TestCase):
         different classes possibly in different modules"""
         # XXX should be catching pyreverse environnement problem but doesn't
         # pyreverse doesn't extracts the relations but this test ok
-        project = MANAGER.project_from_files(['data'], astng_wrapper)
+        project = MANAGER.project_from_files(['data'], astroid_wrapper)
         handler = DiadefsHandler( Config() )
         diadefs = handler.get_diadefs(project, Linker(project, tag=True) )
         cd = diadefs[1]
@@ -146,7 +133,7 @@ class DefaultDiadefGeneratorTC(unittest.TestCase):
         self.assertEqual(relations, self._should_rels)
 
     def test_known_values2(self):
-        project = MANAGER.project_from_files(['data.clientmodule_test'], astng_wrapper)
+        project = MANAGER.project_from_files(['data.clientmodule_test'], astroid_wrapper)
         dd = DefaultDiadefGenerator(Linker(project), HANDLER).visit(project)
         self.assertEqual(len(dd), 1)
         keys = [d.TYPE for d in dd]
@@ -154,9 +141,9 @@ class DefaultDiadefGeneratorTC(unittest.TestCase):
         cd = dd[0]
         self.assertEqual(cd.title, 'classes No Name')
         classes = _process_classes(cd.objects)
-        self.assertEqual(classes, [{'node': True, 'name': 'Ancestor'},
-                                    {'node': True, 'name': 'DoNothing'},
-                                    {'node': True, 'name': 'Specialization'}]
+        self.assertEqual(classes, [(True, 'Ancestor'),
+                                   (True, 'DoNothing'),
+                                   (True, 'Specialization')]
                           )
 
 class ClassDiadefGeneratorTC(unittest.TestCase):
@@ -167,22 +154,20 @@ class ClassDiadefGeneratorTC(unittest.TestCase):
         cd = cdg.class_diagram(PROJECT, special)
         self.assertEqual(cd.title, special)
         classes = _process_classes(cd.objects)
-        self.assertEqual(classes, [{'node': True,
-                                    'name': 'data.clientmodule_test.Ancestor'},
-                                    {'node': True, 'name': special},
-                                    {'node': True,
-                                    'name': 'data.suppliermodule_test.DoNothing'},
-                                    ])
+        self.assertEqual(classes, [(True, 'data.clientmodule_test.Ancestor'),
+                                   (True, special),
+                                   (True, 'data.suppliermodule_test.DoNothing'),
+                                  ])
         
     def test_known_values2(self):
         HANDLER.config.module_names = False
         cd = ClassDiadefGenerator(Linker(PROJECT), HANDLER).class_diagram(PROJECT, 'data.clientmodule_test.Specialization')
         self.assertEqual(cd.title, 'data.clientmodule_test.Specialization')
         classes = _process_classes(cd.objects)
-        self.assertEqual(classes, [{'node': True, 'name': 'Ancestor' },
-                                    {'node': True, 'name': 'DoNothing'},
-                                    {'node': True, 'name': 'Specialization'}
-                                    ])
+        self.assertEqual(classes, [(True, 'Ancestor'),
+                                   (True, 'DoNothing'),
+                                   (True, 'Specialization')
+                                  ])
 
 
 if __name__ == '__main__':
